import React, { useEffect, useRef, useState } from "react";
import {
  StyleSheet,
  View,
  Image,
  Text,
  StatusBar,
  ScrollView,
} from "react-native";
import {
  SCREEN_HEIGHT,
  SCREEN_WIDTH,
} from "react-native-digitcamera/src/common/Constants";
import { translate } from "react-native-digitcamera/src/common/localize/i18n";
import Orientation from "../../../react-native-orientation";
import Geolocation from "@react-native-community/geolocation";
import { getTimeZone } from "react-native-digitcamera/node_modules/react-native-localize";
import { TouchableOpacity } from "react-native-gesture-handler";
import RNFetchBlob from "rn-fetch-blob";
import { SELFSURVEYSERVICE_DOCUMENT_URL } from "react-native-digitcamera/src/Api/ApiUrls";
import ViewShot, { captureRef } from "react-native-view-shot";
import Carousel, { Pagination } from "react-native-snap-carousel";
import Header from "../Screens/Header";
import { PrimaryButton } from "../common/ThemedComponents";

const not_blur = require("../common/Image/not_blur.png");
const Toturial = ({ navigation, route }) => {
  const nextcarousel = useRef();
  const [currentLongitude, SetCurrentLongitude] = useState("Unknown");
  const toturialData = [
    {
      image: not_blur,
      heading: "Before clicking the images, please make sure:",
      subHeading: [
        { points: "Your vechicle us in an open space with good light" },
        { points: "Your vechicle is clean" },
        { points: "Your device camera lens is clean" },
      ],
    },
    {
      image: not_blur,
      heading: "While clicking the images, please make sure:",
      subHeading: [
        { points: "You maintain 4-5 feet distance from your vehicle" },
        { points: "Edges of the vehicle are also captured in the images" },
        { points: "Captured images are not blurred" },
      ],
    },
    {
      image: not_blur,
      heading: "Keep the vehicle Registration Certificate (RC Copy) handy",
      subHeading: [],
    },
    {
      image: not_blur,
      heading:
        "To help you click the correct image, simply refer to the image and instructions given at each step and you will be done in no time!",
      subHeading: [],
    },
  ];
  useEffect(() => {}, []);

  const _renderToturial = ({ item, index }) => {
    return (
      <View style={{ margin: 24, flex: 1 }}>
        {/* Image view */}
        <View style={styles.imageView}>
          <Image
            source={item.image}
            style={{
              width: SCREEN_WIDTH - 100,
              height: SCREEN_WIDTH / 1.47,
              alignSelf: "center",
              resizeMode: "contain",
            }}
          />
        </View>
        {/* info View */}
        <View style={styles.InfoView}>
          <Text style={styles.headingText}>{translate(item.heading)}</Text>
          {item.subHeading?.map((item) => {
            return (
              <Text style={styles.pointText}>
                {"\u2022"}
                {" " + translate(item.points)}
              </Text>
            );
          })}
        </View>
        <View>
          <Pagination
            style={{ justifyContent: "" }}
            dotsLength={toturialData.length}
            activeDotIndex={index}
            containerStyle={{ alignContent: "flex-end" }}
            dotStyle={{
              width: 11,
              height: 6,
              borderRadius: 5,
              marginHorizontal: 6,
              backgroundColor: "#000000",
            }}
            inactiveDotStyle={{
              // Define styles for inactive dots here
              width: 6,
              height: 6,
              borderRadius: 5,
              marginHorizontal: 6,
              backgroundColor: "#DDDDDD",
            }}
            inactiveDotOpacity={0.4}
            inactiveDotScale={0.6}
          />
        </View>
      </View>
    );
  };
  return (
    <View style={styles.main}>
      <Header />
      <StatusBar hidden={true} />
      <View style={{ flex: 0.9 }}>
        <Carousel
          ref={nextcarousel}
          data={toturialData}
          renderItem={_renderToturial}
          sliderWidth={SCREEN_WIDTH}
          itemWidth={SCREEN_WIDTH}
          autoplay={false}
          loop={true}
        />
      </View>
      <View
        style={{
          marginLeft: 24,
          marginRight: 24,
          width: SCREEN_WIDTH - 48,
          height: 1,
          backgroundColor: "#F5F5F5",
        }}
      />
      <View style={styles.buttonView}>
        <PrimaryButton onPress={() => {}}>{"Next"}</PrimaryButton>
      </View>
    </View>
  );
};
export default Toturial;

const styles = StyleSheet.create({
  main: {
    flex: 1,
    backgroundColor: "#FFFFFF",
  },
  imageView: {
    flex: 0.6,
    justifyContent: "center",
  },
  InfoView: {
    flex: 0.4,
  },
  headingText: {
    fontFamily: "Muli-Bold",
    fontSize: 20,
    marginBottom: 16,
    marginTop: 24,
  },
  pointText: {
    fontSize: 18,
    fontFamily: "Muli-Regular",
    lineHeight: 30,
  },
  buttonView: {
    flex: 0.1,
    marginLeft: 24,
    marginRight: 24,
    justifyContent: "center",
  },
});
