import React, { useState, useEffect } from "react";
import { ScrollView, StyleSheet, Text, View, Image } from "react-native";
import { SCREEN_WIDTH, SCREEN_HEIGHT } from "../common/Constants";
import VideoPlayer from "react-native-video-player";
import { translate } from "react-native-digitcamera/src/common/localize/i18n";
import WarningContent from '../common/WarningContent'
import { TextInput } from "../common/ThemedComponents";

const VechicleSurveyInstruction = ({ title, subTitle, points, image }) => {
  const [logoutModelVisible, setLogoutModelVisible] = useState(false);
  useEffect(() => {}, []);

  return (
    <ScrollView>
      {console.log("Title   >>> ", title)}
      <View style={styles.main}>
        <View style={styles.vechicleImageView}>
          {title != "Take a 360° video" ? (
            <Image
              source={{ uri: image }}
              style={{
                width: SCREEN_WIDTH - 48,
                height: SCREEN_WIDTH / 2,
                alignSelf: "center",
              }}
            />
          ) : (
            <VideoPlayer
              video={{ uri: image }}
              videoHeight={SCREEN_HEIGHT}
              videoWidth={SCREEN_WIDTH - 48}
              pauseOnPress={true}
              autoplay={true}
              disableSeek={true}
              style={styles.productImageStyle}
            ></VideoPlayer>
          )}
        </View>
        {/* Title View */}
        <View style={styles.titleView}>
          {title == "Take a 360° video" ? (
            <Text
              style={{
                fontFamily: "Muli-SemiBold",
                fontSize: 12,
                color: "#999999",
                marginBottom: 29,
              }}
            >
              {"SAMPLE VIDEO"}
            </Text>
          ) : null}
          <Text style={styles.titleStyle}>{title}</Text>

          {/*  display only for odometer*/}
       {title=="Enter the vehicle, turn it on and take images of your odometer"?
       (
              <TextInput
             style={{marginTop:20}}
              label={'Enter Odometer Reading (in Km)'}
              // value={companyName}
              // onChangeText={value => {
              //   setCompanyName(value);
              // }}
            />
       ):null}
        </View>
        {/* subTitle View */}
        <View style={styles.subTitleView}>
          <Text style={styles.subTitleText}>{subTitle}</Text>
        </View>
        {/* points View */}
        <View style={styles.pointsView}>
          {points.map((item) => {
            return (
              <Text style={styles.pointsText}>
                {"\u2022 "}
                {item.instructionData.includes("Note:")?item.instructionData.split("Note:")[0].trim():item.instructionData.split(".").join("")}
                
              </Text>
            );
          })}
        </View>
           {points.map(item=>{
             if(item.instructionData.includes("Note:")){
             return(
                      <WarningContent
                style={{marginTop:16}}
                      textContent={"Note:"+item.instructionData.split("Note:")[1].split(".").join("")}
          >
          </WarningContent>
             )
             }
           })}
      </View>
    </ScrollView>
  );
};
const styles = StyleSheet.create({
  main: {
    backgroundColor: "#FFFFFF",
    flex: 1,
    marginRight: 24,
    marginLeft: 24,
    marginTop: 48,
  },
  vechicleImageView: {
    width: SCREEN_WIDTH - 48,
    height: (SCREEN_WIDTH - 48) / 2,
    justifyContent: "center",
  },
  titleStyle: {
    fontSize: 20,
    fontFamily: "Muli-Black",
  },
  pointsText: {
    fontSize: 16,
    fontFamily: "Muli-Regular",
    flex: 1,
    lineHeight: 32,
  },
  titleView: {
    marginTop: 48,
  },
  subTitleView: {
    marginTop: 16,
  },
  subTitleText: {
    fontFamily: "Muli-SemiBold",
    fontSize: 16,
  },
  pointsView: {
    marginTop: 18,
  },
  productImageStyle: {
    height: SCREEN_HEIGHT - 70,
  },
});
export default VechicleSurveyInstruction;
