import { SCREEN_HEIGHT, SCREEN_WIDTH } from "./Constants";
import {
  View,
  Text,
  StyleSheet,
  ScrollView,
  TouchableOpacity,
  StatusBar,
} from "react-native";
import React, { Component } from "react";
import { Image } from "react-native";
import Colors from "./Colors";
import { RNCamera } from "react-native-camera";
import Icon from "react-native-vector-icons/FontAwesome";
import moment from "react-moment";
import Geolocation from "@react-native-community/geolocation";

const crossMark = require("./Image/crossMark.png");
const tickMark = require("./Image/tickMark.png");

export default class VideoRecorder extends Component {
  constructor(props) {
    super(props);
    this.state = {
      isDisplayQuoteInstruction: true,
      isWithQuote: true,
      isWithOutQuote: false,
      isDisplayInstruction: false,
      torchon: "",
      isDisplayCameraPreview: false,
      isDisplayCamera: false,
      localPath: "",
      flashState: true, //for flash
      dateAndTime: "", //date and time
      currentLongitude: "unknown", //Initial Longitude
      currentLatitude: "unknown", //Initial Latitude
      isDisplayVideoRecorder: false,
      fullDataSource: "",
      assets: "",
      header: "",
      count: 0,
      dataSource: "",
      cameraState: "",
      buttonText: "",
      skipdata: "",
      isBackButtonPressed: false,
      isSkipButtonPressed: false,
      screenShotPath: "",
      isDisplayUploadDocument: false,
      upLoadIamgeDataSource: [],
      documentUploadPercentage: 0,
      odometerReading: "",
      ANDROID_ID: "",
      CurrentDate: "",
      showError: false,
      isLoading: true,
      registrationNumber: "",
      isSelected: false,
      isFocused: false,
      staincil: this.props.navigation.state.params.staincil,
      count: this.props.navigation.state.params.count,
      productImage: this.props.navigation.state.params.productImage,
      extention: this.props.navigation.state.params.extention,
      stepTitle: this.props.navigation.state.params.stepTitle,
      instructionData: this.props.navigation.state.params.instructionData,
    };
  }

  /*
                              %%%%%%%%%%%%% For Video Record %%%%%%%%%%%%%%%%
   */

  async startRecording() {
    this.setState({ recording: true });
    // default to mp4 for android as codec is not set
    const options = { quality: 0.2, base64: true };
    const { uri, codec = "mp4" } = await this.camera.recordAsync(options);
    this.setState({ localPath: uri });
    this.props.navigation.navigate("VideoPreview", {
      localPath: this.state.localPath,
      finalWatermarkResult: this.state.finalWatermarkResult,
      count: this.state.count,
      productImage: this.state.productImage,
      stepTitle: this.state.stepTitle,
      extention: this.state.extention,
      instructionData: this.state.instructionData,
    });
  }

  //Stop Recording
  stopRecording() {
    this.camera.stopRecording();
    this.setState({ recording: false });
  }

  render() {
    const { recording, processing } = this.state;

    let button = (
      <View
        style={{
          flex: 1,
          position: "absolute",
          width: SCREEN_WIDTH,
          height: SCREEN_HEIGHT,
        }}
      >
        <View style={{ flex: 0.5, justifyContent: "flex-end" }}>
          <TouchableOpacity
            onPress={() => [this.startRecording()]}
            style={styles.capture}
          >
            {/* <Text style={{ fontSize: 14 }}> SNAP </Text> */}
            <Icon name="video-camera" />
          </TouchableOpacity>
        </View>
      </View>
    );

    if (recording) {
      button = (
        <View
          style={{
            flex: 1,
            position: "absolute",
            width: SCREEN_WIDTH,
            height: SCREEN_HEIGHT,
          }}
        >
          <View style={{ flex: 0.5, justifyContent: "flex-end" }}>
            <TouchableOpacity
              onPress={() => [this.stopRecording()]}
              style={styles.capture}
            >
              {/* <Text style={{ fontSize: 14 }}> SNAP </Text> */}
              <Icon name="video-off-outline" />
            </TouchableOpacity>
          </View>
        </View>
      );
    }
    return (
      <View style={styles.container}>
        <StatusBar hidden={true} />
        <RNCamera
          ref={(ref) => {
            this.camera = ref;
          }}
          style={styles.preview}
          type={RNCamera.Constants.Type.back}
          flashMode={RNCamera.Constants.FlashMode.on}
          permissionDialogTitle={"Permission to use camera"}
          permissionDialogMessage={
            "We need your permission to use your camera phone"
          }
        >
          {({ camera, status, recordAudioPermissionStatus }) => {
            // if (status !== 'READY') return <PendingView />;
            return (
              <View
                style={{
                  flex: 1,
                  position: "absolute",
                  width: SCREEN_WIDTH,
                  height: SCREEN_HEIGHT,
                }}
              >
                <Image
                  source={crossMark}
                  style={{
                    width: 50,
                    height: 50,
                    position: "absolute",
                    left: 1,
                  }}
                />
                <Image
                  source={crossMark}
                  style={{
                    width: 50,
                    height: 50,
                    position: "absolute",
                    left: 1,
                    bottom: 1,
                  }}
                />
                <Image
                  source={crossMark}
                  style={{
                    width: 50,
                    height: 50,
                    position: "absolute",
                    right: 1,
                    bottom: 1,
                  }}
                />
                <Image
                  source={crossMark}
                  style={{
                    width: 50,
                    height: 50,
                    position: "absolute",
                    right: 1,
                  }}
                />
                {button}
              </View>
            );
          }}
        </RNCamera>
      </View>
    );
  }
}
const styles = StyleSheet.create({
  main: {
    flex: 1,
    flexDirection: "row",
  },
  productImageView: {
    flex: 0.475,
  },
  blankView: {
    flex: 0.05,
  },
  productInfoView: {
    flex: 0.475,
    marginRight: 16,
    width: SCREEN_WIDTH,
    height: SCREEN_HEIGHT,
  },
  headerView: {
    backgroundColor: "#C6AFFF",
    height: 40,
    justifyContent: "center",
  },
  headerText: {
    marginLeft: 16,
    fontSize: 20,
    fontFamily: "Muli-Black",
  },
  productImageStyle: {
    marginTop: 8,
    marginLeft: 16,
    marginBottom: 40,
    height: SCREEN_HEIGHT - 70,
  },
  backButtonImageStyle: {
    marginLeft: 32,
    height: 24,
    width: 24,
    backgroundColor: "red",
  },
  subHeaderText: {
    fontFamily: "Mulli-Regular",
    fontSize: 16,
    marginLeft: 16,
  },
  instructionText: {
    fontFamily: "Mulli-Regular",
    fontSize: 16,
    marginLeft: 16,
    marginBottom: 20,
  },
  captureImageButtonView: {
    height: 48,
    borderRadius: 4,
    backgroundColor: Colors.digitYellow,
    marginTop: 2,
    flexDirection: "row",
    justifyContent: "center",
  },
  captureImageButtonText: {
    fontSize: 16,
    fontFamily: "Muli-Black",
    alignSelf: "center",
  },
  container: {
    flex: 1,
    // flexDirection: 'row',
    // backgroundColor: 'black',
  },
  preview: {
    flex: 1,
    justifyContent: "flex-end",
    alignItems: "center",
  },
  capture: {
    flex: 0,
    backgroundColor: "#fff",
    borderRadius: 5,
    padding: 15,
    paddingHorizontal: 20,
    alignSelf: "flex-end",
    margin: 20,
    position: "absolute",
  },
  flash: {
    flex: 0,
    backgroundColor: "#fff",
    borderRadius: 5,
    padding: 15,
    paddingHorizontal: 20,
    alignSelf: "flex-end",
    margin: 20,
    position: "absolute",
  },
  previewImageStyle: {
    width: SCREEN_WIDTH,
    height: SCREEN_HEIGHT,
  },
  dateAndTimeText: {
    position: "absolute",
    fontSize: 20,
    color: Colors.digitYellow,
    left: 1,
    bottom: 1,
  },
  previewImageIconMainView: {
    flex: 0.05,
    backgroundColor: "black",
  },
  tickMarkImageView: {
    flex: 0.6,
    justifyContent: "flex-end",
  },
  tickMarkImageStyle: {
    width: 30,
    height: 30,
    backgroundColor: "white",
    alignContent: "flex-end",
    marginBottom: 20,
  },
  crossImageView: {
    flex: 0.4,
    justifyContent: "flex-end",
    marginBottom: 20,
  },
  crossImageStyle: {
    width: 30,
    height: 30,
    backgroundColor: "white",
    alignContent: "flex-end",
  },
  cameraIconView: {
    flexDirection: "row",
    justifyContent: "center",
    width: SCREEN_WIDTH,
    position: "absolute",
  },
  infoScrollView: {
    marginTop: 40,
    height: SCREEN_HEIGHT - 200,
  },
  subHeaderTextView: {
    height: 40,
    marginTop: 8,
  },
  backButtonImageView: {
    backgroundColor: "#C6AFFF",
    height: 40,
    justifyContent: "center",
    marginLeft: 16,
  },
  latLongText: {
    position: "absolute",
    fontSize: 20,
    color: Colors.digitYellow,
    left: 1,
  },
  digitEdgeText: {
    position: "absolute",
    fontSize: 20,
    color: Colors.digitYellow,
    right: 1,
  },
});
